@@ -1,22 +1,12 @@
-/* Include file for fax routines
-   Copyright (C) 1990, 1995  Frank D. Cringle.
-   Copyright (C) 2005  Helge Deller <deller@kde.org>
+/*
+    Include file for fax routines
+    This file is part of viewfax - g3/g4 fax processing software.
 
-This file is part of viewfax - g3/g4 fax processing software.
+    SPDX-FileCopyrightText: 1990, 1995  Frank D. Cringle.
+    SPDX-FileCopyrightText: 2005  Helge Deller <deller@kde.org>
 
-viewfax is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2 of the License, or (at your
-option) any later version.
-
-This program is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _faxexpand_h_
 #define _faxexpand_h_
@@ -73,9 +63,9 @@ public:
     QPoint dpi;           /* DPI horz/vert */
     void (*expander)(class pagenode *, drawfunc);
     unsigned int bytes_per_line;
-    QString filename; /* The name of the file to be opened */
-    QImage image;     /* The final image */
-    uchar *imageData; /* The temporary raw image data */
+    QString filename;           /* The name of the file to be opened */
+    QImage image;               /* The final image */
+    uchar *imageData = nullptr; /* The temporary raw image data */
 };
 
 /* page orientation flags */
