@@ -132,7 +132,7 @@ QImage KIMGIOGenerator::image(Okular::PixmapRequest *request)
         int width = request->width();
         int height = request->height();
         if (request->page()->rotation() % 2 == 1) {
-            qSwap(width, height);
+            std::swap(width, height);
         }
 
         return m_img.scaled(width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
